MenuItem

Enum MenuItem 

pub enum MenuItem {
    Action(ActionItem),
    Separator(SeparatorItem),
    SubMenu(SubMenuItem),
}

Variants



Action(ActionItem)



Separator(SeparatorItem)



SubMenu(SubMenuItem)

Implementations

Source

impl MenuItem

pub fn text(&self) -> Option<&str>

Gets the text of the menu item (if applicable).

pub fn is_enabled(&self) -> bool

Checks if the menu item is enabled.

pub fn label(&self) -> Option<&str>

Returns the label of this menu item, if any.

pub fn hotkey(&self) -> Option<char>

Returns the hotkey of this menu item, if any.

pub fn is_selectable(&self) -> bool

Returns whether this menu item is selectable.

Source

impl MenuItem

pub fn new_action<S: Into<String>, C: Into<Command>>( label: S, command: C, ) -> Self

Creates a new action menu item.

pub fn action_with_hotkey<S: Into<String>, C: Into<Command>>( label: S, command: C, hotkey: char, ) -> Self

Creates a new action menu item with hotkey.

pub fn action_with_all<S: Into<String>, C: Into<Command>>( label: S, command: C, hotkey: Option<char>, shortcut: Option<S>, ) -> Self

Creates a new action menu item with all properties.

pub fn separator() -> Self

Creates a new separator menu item.

pub fn new_submenu<S: Into<String>>(label: S) -> Self

Creates a new submenu item.

pub fn submenu_with_hotkey<S: Into<String>>(label: S, hotkey: char) -> Self

Creates a new submenu item with hotkey.

pub fn submenu_with_items<S: Into<String>>( label: S, hotkey: Option<char>, items: Vec<MenuItem>, ) -> Self

Creates a new submenu item with all properties.

pub fn action<S: Into<String>, C: Into<Command>>(text: S, command: C) -> Self

Creates a new action menu item (legacy).

pub fn submenu<S: Into<String>>(text: S, items: Vec<MenuItem>) -> Self

Creates a new submenu (legacy).

pub fn with_hotkey(self, hotkey: char) -> Self

Sets the hotkey for this menu item (legacy builder pattern).

pub fn with_shortcut<S: Into<String>>(self, shortcut: S) -> Self

Sets the shortcut display for this menu item (legacy builder pattern).

pub fn with_help_context<S: Into<String>>(self, help_context: S) -> Self

Sets the help context for the menu item (legacy builder pattern).

pub fn with_enabled(self, enabled: bool) -> Self

Sets the enabled state of the menu item (legacy builder pattern).