MenuBar

Struct MenuBar 

pub struct MenuBar {
    pub menus: Vec<Menu>,
    pub opened_menu: Option<usize>,
    pub theme: MenuTheme,
}
A menu bar widget that will be displayed at the top of the screen.

Only one menu can be open at a time. When a menu is opened, it displays its dropdown and becomes the active menu for keyboard navigation.

Fields

menus: Vec<Menu>

Collection of menus in the menu bar

opened_menu: Option<usize>

Index of the currently opened menu (None means no menu is open)

theme: MenuTheme

Theme configuration for rendering

Implementations

Source

impl MenuBar

pub fn new() -> Self

Creates a new empty menu bar.

pub fn from_menus<I, S>(menus: I) -> Self
where I: IntoIterator<Item = (S, Option<char>, Vec<MenuItem>)>, S: Into<String>,

Creates a new menu bar from menu definitions.

Example
use tui_vision::menus::{MenuBar, MenuItem};

let menu_bar = MenuBar::from_menus([
    ("File", Some('F'), vec![
        MenuItem::new_action("New", "file.new"),
        MenuItem::separator(),
        MenuItem::new_action("Exit", "file.exit"),
    ]),
    ("Edit", Some('E'), vec![
        MenuItem::new_action("Undo", "edit.undo"),
        MenuItem::new_action("Redo", "edit.redo"),
    ]),
]);
pub fn with_menus(menus: Vec<Menu>) -> Self

Creates a new menu bar with the given menus.

Example
use tui_vision::menus::{MenuBar, Menu};

let menu_bar = MenuBar::with_menus(vec![
    Menu::new("File").hotkey('F'),
    Menu::new("Edit").hotkey('E'),
]);
pub fn add_menu(&mut self, menu: Menu) -> &mut Self

Adds a menu to the menu bar (builder pattern).

pub fn set_theme(&mut self, theme: MenuTheme) -> &mut Self

Sets the theme for the menu bar.

pub fn theme(self, theme: MenuTheme) -> Self

Sets the theme for the menu bar (builder pattern).

pub fn get_theme(&self) -> &MenuTheme

Gets a reference to the current theme.

Source

impl MenuBar

pub fn handle_key_event(&mut self, key: KeyEvent) -> MenuEventResult

Handles a keyboard event for the menu system.

Returns a MenuEventResult indicating what happened as a result of the key press. The caller can use this to update status messages, handle commands, etc.

Source

impl MenuBar

pub fn has_open_menu(&self) -> bool

Check if any menu is currently open.

pub fn opened_menu(&self) -> Option<&Menu>

Get the currently opened menu.

pub fn opened_menu_mut(&mut self) -> Option<&mut Menu>

Get the currently opened menu mutably.

pub fn open_menu(&mut self, index: usize)

Open a specific menu by index.

pub fn close_menu(&mut self)

Close the currently opened menu.

pub fn open_next_menu(&mut self)

Open the next menu.

pub fn open_previous_menu(&mut self)

Open the previous menu.