pub enum MenuItem {
Action(ActionItem),
Separator(SeparatorItem),
SubMenu(SubMenuItem),
}Variants
Implementations
Sourceimpl MenuItem
impl MenuItem
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Checks if the menu item is enabled.
Sourcepub fn is_selectable(&self) -> bool
pub fn is_selectable(&self) -> bool
Returns whether this menu item is selectable.
Sourceimpl MenuItem
impl MenuItem
Sourcepub fn new_action<S: Into<String>, C: Into<Command>>(
label: S,
command: C,
) -> Self
pub fn new_action<S: Into<String>, C: Into<Command>>( label: S, command: C, ) -> Self
Creates a new action menu item.
Sourcepub fn action_with_hotkey<S: Into<String>, C: Into<Command>>(
label: S,
command: C,
hotkey: char,
) -> Self
pub fn action_with_hotkey<S: Into<String>, C: Into<Command>>( label: S, command: C, hotkey: char, ) -> Self
Creates a new action menu item with hotkey.
Sourcepub fn action_with_all<S: Into<String>, C: Into<Command>>(
label: S,
command: C,
hotkey: Option<char>,
shortcut: Option<S>,
) -> Self
pub fn action_with_all<S: Into<String>, C: Into<Command>>( label: S, command: C, hotkey: Option<char>, shortcut: Option<S>, ) -> Self
Creates a new action menu item with all properties.
Creates a new submenu item.
Creates a new submenu item with hotkey.
Creates a new submenu item with all properties.
Sourcepub fn action<S: Into<String>, C: Into<Command>>(text: S, command: C) -> Self
pub fn action<S: Into<String>, C: Into<Command>>(text: S, command: C) -> Self
Creates a new action menu item (legacy).
Creates a new submenu (legacy).
Sourcepub fn with_hotkey(self, hotkey: char) -> Self
pub fn with_hotkey(self, hotkey: char) -> Self
Sets the hotkey for this menu item (legacy builder pattern).
Sourcepub fn with_shortcut<S: Into<String>>(self, shortcut: S) -> Self
pub fn with_shortcut<S: Into<String>>(self, shortcut: S) -> Self
Sets the shortcut display for this menu item (legacy builder pattern).
Sourcepub fn with_help_context<S: Into<String>>(self, help_context: S) -> Self
pub fn with_help_context<S: Into<String>>(self, help_context: S) -> Self
Sets the help context for the menu item (legacy builder pattern).
Sourcepub fn with_enabled(self, enabled: bool) -> Self
pub fn with_enabled(self, enabled: bool) -> Self
Sets the enabled state of the menu item (legacy builder pattern).