pub struct MenuBar {
pub menus: Vec<Menu>,
pub opened_menu: Option<usize>,
pub theme: MenuTheme,
}Expand description
A menu bar widget that will be displayed at the top of the screen.
Only one menu can be open at a time. When a menu is opened, it displays its dropdown and becomes the active menu for keyboard navigation.
Fields
Collection of menus in the menu bar
Index of the currently opened menu (None means no menu is open)
theme: MenuThemeTheme configuration for rendering
Implementations
Sourceimpl MenuBar
impl MenuBar
Creates a new menu bar from menu definitions.
Example
use tui_vision::menus::{MenuBar, MenuItem};
let menu_bar = MenuBar::from_menus([
("File", Some('F'), vec![
MenuItem::new_action("New", "file.new"),
MenuItem::separator(),
MenuItem::new_action("Exit", "file.exit"),
]),
("Edit", Some('E'), vec![
MenuItem::new_action("Undo", "edit.undo"),
MenuItem::new_action("Redo", "edit.redo"),
]),
]);Creates a new menu bar with the given menus.
Example
use tui_vision::menus::{MenuBar, Menu};
let menu_bar = MenuBar::with_menus(vec![
Menu::new("File").hotkey('F'),
Menu::new("Edit").hotkey('E'),
]);Adds a menu to the menu bar (builder pattern).
Sourceimpl MenuBar
impl MenuBar
Sourcepub fn handle_key_event(&mut self, key: KeyEvent) -> MenuEventResult
pub fn handle_key_event(&mut self, key: KeyEvent) -> MenuEventResult
Handles a keyboard event for the menu system.
Returns a MenuEventResult indicating what happened as a result of the key press.
The caller can use this to update status messages, handle commands, etc.