pub struct SubMenuItem {
pub label: String,
pub items: Vec<MenuItem>,
pub enabled: bool,
pub hotkey: Option<char>,
pub help_context: Option<String>,
pub focused_item: Option<usize>,
pub is_open: bool,
}Expand description
A submenu containing other menu items.
Fields
label: StringText label displayed to the user
items: Vec<MenuItem>Collection of menu items in the submenu
enabled: boolWhether the submenu is enabled
hotkey: Option<char>Optional hotkey for quick access
help_context: Option<String>Help context for additional information
focused_item: Option<usize>Index of the currently focused item when this submenu is open
is_open: boolWhether this submenu is currently open
Implementations
Sourceimpl SubMenuItem
impl SubMenuItem
Sourcepub fn with_hotkey<S: Into<String>>(label: S, hotkey: char) -> Self
pub fn with_hotkey<S: Into<String>>(label: S, hotkey: char) -> Self
Creates a new submenu item with label and hotkey.
Sourcepub fn with_items<S: Into<String>>(
label: S,
hotkey: Option<char>,
items: Vec<MenuItem>,
) -> Self
pub fn with_items<S: Into<String>>( label: S, hotkey: Option<char>, items: Vec<MenuItem>, ) -> Self
Creates a new submenu item with title, hotkey, and items.
Example
use tui_vision::menus::{SubMenuItem, MenuItem};
let submenu = SubMenuItem::with_items("Find", Some('F'), vec![
MenuItem::new_action("Find", "edit.find"),
MenuItem::new_action("Find Next", "edit.find_next"),
]);Sourcepub fn hotkey(self, hotkey: char) -> Self
pub fn hotkey(self, hotkey: char) -> Self
Sets the hotkey for this submenu item (builder pattern).
Sourcepub fn help_context<S: Into<String>>(self, help_context: S) -> Self
pub fn help_context<S: Into<String>>(self, help_context: S) -> Self
Sets the help context for this submenu item (builder pattern).